@@ -30,7 +30,7 @@ def export_nc(geom, metadata, alpha, wave, thres, fname, dir_out):
     geom_dts.dilation.attrs['units'] = 'Km'
     geom_dts.dilation.attrs['long_name'] = 'The dillation value (window) used for the wavelet covariance transform calculations'
     
-    geom_dts['wavelength'] = wave
+    geom_dts['wavelength'] = float(wave)
     geom_dts.wavelength.attrs['units'] = 'nm'
     geom_dts.wavelength.attrs['long_name'] = 'The wavelength of the ELDA product used to obtain the geometrical properties'
 
@@ -68,25 +68,27 @@ def export_nc(geom, metadata, alpha, wave, thres, fname, dir_out):
         
     return(geom_dts)
 
-def nc_name(metadata, prod_id, wave):
+def nc_name(metadata, prod_id, wave, ver):
     
     parser = configparser.ConfigParser()
-    parser.read('./../default.ini')
+    parser.read('./default.ini')
     
     app = parser._sections['info']['name']
     ver = parser._sections['info']['version']
-    
+
     ms_id = metadata['measurement_ID']
     
-    st_id = metadata['station_ID'].zfill(7)
+    st_id = metadata['station_ID']
+    
+    prod_id = prod_id.zfill(7)
     
     wave = wave.zfill(4)
     
-    start_t = parse_date.parse(metadata[0]['measurement_start_datetime'])\
+    start_t = parse_date.parse(metadata['measurement_start_datetime'])\
         .strftime('%Y%m%d%H%M')
-    stop_t = parse_date.parse(metadata[0]['measurement_stop_datetime'])\
+    stop_t = parse_date.parse(metadata['measurement_stop_datetime'])\
         .strftime('%Y%m%d%H%M')
         
     fname = f'{st_id}_{wave}_{prod_id}_{start_t}_{stop_t}_{ms_id}_{app}_v{ver}.nc'
-    
+
     return(fname)
\ No newline at end of file
